netapp_ontap.models.rfc2307 API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.rfc2307`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class Rfc2307Schema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the Rfc2307 object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `attribute: Rfc2307Attribute GET PATCH`

    The attribute field of the rfc2307.

  `cn: Cn GET PATCH`

    The cn field of the rfc2307.

  `member: Member GET PATCH`

    The member field of the rfc2307.

  `nis: Nis GET PATCH`

    The nis field of the rfc2307.

  `posix: Posix GET PATCH`

    The posix field of the rfc2307.